@@ -32,6 +32,10 @@ from .task import RequestTask
 
 from .utils import create_task_class_type, create_user_class_type
 
+__all__ = [
+    'subprocess',
+]
+
 
 unhandled_greenlet_exception = False
 
@@ -175,7 +179,9 @@ def setup_environment_listeners(context: Context, environment: Environment, requ
     environment.events.init.add_listener(init(testdata))
     environment.events.test_start.add_listener(locust_test_start(grizzly))
     environment.events.test_stop.add_listener(locust_test_stop)
-    environment.events.spawning_complete.add_listener(spawning_complete(grizzly))
+
+    if not on_master(context):
+        environment.events.spawning_complete.add_listener(spawning_complete(grizzly))
 
     # And save statistics to "..."
     if grizzly.setup.statistics_url is not None:
@@ -232,11 +238,15 @@ def run(context: Context) -> int:
         external_dependencies.update(variable_dependencies)
 
         if not on_master(context) and len(external_dependencies) > 0:
+            env = environ.copy()
+            if grizzly.state.verbose:
+                env['GRIZZLY_EXTRAS_LOGLEVEL'] = 'DEBUG'
+
             for external_dependency in external_dependencies:
                 logger.info(f'starting {external_dependency}')
                 external_processes.update({external_dependency: subprocess.Popen(
                     [external_dependency],
-                    env=environ.copy(),
+                    env=env,
                     shell=False,
                     stdout=subprocess.PIPE,
                     stderr=subprocess.STDOUT,
@@ -285,7 +295,7 @@ def run(context: Context) -> int:
         class LocustOption:
             headless: bool
             num_users: int
-            spawn_rate: int
+            spawn_rate: float
 
         setattr(environment, 'parsed_options', LocustOption())
         setattr(environment.parsed_options, 'headless', True)
@@ -310,6 +320,7 @@ def run(context: Context) -> int:
             )
 
         if not on_worker(context):
+            logger.info('starting locust via grizzly')
             environment.runner.start(grizzly.setup.user_count, grizzly.setup.spawn_rate)
 
             stats_printer_greenlet = gevent.spawn(stats_printer(environment.stats))
@@ -338,17 +349,18 @@ def run(context: Context) -> int:
             logger.info(f'{runner.user_count=}, stopping runner')
             gevent.sleep(3.0)
 
-        # start watching for user_count after 5 second
-        while not grizzly.state.spawning_complete:
-            gevent.sleep(1.0)
+        if not on_master(context):
+            while not grizzly.state.spawning_complete:
+                logger.debug('spawning not complete...')
+                gevent.sleep(1.0)
 
-        logger.info('all users spawn, start watching user count')
+            logger.info('all users spawn, start watching user count')
 
-        watch_active_users_greenlet = gevent.spawn(watch_active_users)
-        watch_active_users_greenlet.link_exception(greenlet_exception_handler)
+            watch_active_users_greenlet = gevent.spawn(watch_active_users)
+            watch_active_users_greenlet.link_exception(greenlet_exception_handler)
 
-        # shutdown when user_count reaches 0
-        main_greenlet = watch_active_users_greenlet
+            # shutdown when user_count reaches 0
+            main_greenlet = watch_active_users_greenlet
 
         def shutdown() -> int:
             logger.info('running teardowns...')
@@ -388,7 +400,6 @@ def run(context: Context) -> int:
 
         gevent.signal_handler(SIGTERM, sig_term_handler)
 
-        logger.info('starting locust via behave')
         try:
             main_greenlet.join()
         except KeyboardInterrupt as e:
