@@ -1,10 +1,21 @@
-'''Communicates with IBM MQ.
+'''Get and put messages on with IBM MQ queues.
 
 User is based on `pymqi` for communicating with IBM MQ. However `pymqi` uses native libraries which `gevent` (used by `locust`) cannot patch,
 which causes any calls in `pymqi` to block the rest of `locust`. To get around this, the user implementation communicates with a stand-alone
-process via zmq, which then in turn communicates with IBM MQ.
+process via zmq, which in turn communicates with IBM MQ.
 
-The message queue daemon process is started automagically when a scenario contains the `MessageQueueUser` and `pymqi` dependencies are installed.
+`async-messaged` starts automagically when a scenario uses `MessageQueueUser` and `pymqi` dependencies are installed.
+
+## Request methods
+
+Supports the following request methods:
+
+* send
+* put
+* get
+* receive
+
+## Format
 
 Format of `host` is the following:
 
@@ -14,21 +25,15 @@ mq://<hostname>:<port>/?QueueManager=<queue manager name>&Channel=<channel name>
 
 `endpoint` in the request is the name of an MQ queue.
 
+## Examples
+
 Example of how to use it in a scenario:
 
 ```gherkin
 Given a user of type "MessageQueue" load testing "mq://mq.example.com/?QueueManager=QM01&Channel=SRVCONN01"
 Then put request "test/queue-message.j2.json" with name "queue-message" to endpoint "INCOMING.MESSAGES"
 ```
-
-Supports the following request methods:
-
-* send
-* put
-* get
-* receive
-
-## GET / RECEIVE
+### Get message
 
 Default behavior is to fail directly if there is no message on the queue. If the request should wait until a message is available,
 set the time it should wait with `message.wait` (seconds) context variable.
@@ -41,9 +46,9 @@ Then get request with name "get-queue-message" from endpoint "INCOMING.MESSAGES"
 
 In this example, the request will not fail if there is a message on queue within 5 seconds.
 
-## Authentication
+### Authentication
 
-### Username and password
+#### Username and password
 
 ```gherkin
 Given a user of type "MessageQueue" load testing "mq://mqm:admin@mq.example.com/?QueueManager=QM01&Channel=SRVCONN01"
@@ -51,7 +56,7 @@ And set context variable "auth.username" to "<username>"
 And set context variable "auth.password" to "<password>"
 ```
 
-### With TLS
+#### With TLS
 
 A [key repository](https://www.ibm.com/docs/en/ibm-mq/7.5?topic=wstulws-setting-up-key-repository-unix-linux-windows-systems)
 (3 files; `.kdb`, `.rdb` and `.sth`) for the user is needed, and is specified with `auth.key_file` excluding the file extension.
@@ -71,18 +76,18 @@ from typing import Dict, Any, Generator, Tuple, Optional, cast
 from urllib.parse import urlparse, parse_qs, unquote
 from contextlib import contextmanager
 from time import monotonic as time
-from grizzly_extras.messagequeue import MessageQueueContext, MessageQueueRequest, MessageQueueResponse
 
 
 import zmq
 
 
 from gevent import sleep as gsleep
-from locust.exception import StopUser, CatchResponseError
+from locust.exception import StopUser
+from grizzly_extras.async_message import AsyncMessageContext, AsyncMessageRequest, AsyncMessageResponse, AsyncMessageError
 
-from .meta import ContextVariables, ResponseHandler, RequestLogger
 from ..task import RequestTask
 from ..utils import merge_dicts
+from .meta import ContextVariables, ResponseHandler, RequestLogger
 from . import logger
 
 
@@ -108,9 +113,9 @@ class MessageQueueUser(ResponseHandler, RequestLogger, ContextVariables):
         }
     }
 
-    __dependencies__ = set(['messagequeue-daemon'])
+    __dependencies__ = set(['async-messaged'])
 
-    mq_context: MessageQueueContext
+    am_context: AsyncMessageContext
     worker_id: Optional[str]
     zmq_context = zmq.Context()
     zmq_client: zmq.Socket
@@ -139,7 +144,8 @@ class MessageQueueUser(ResponseHandler, RequestLogger, ContextVariables):
 
         port = parsed.port or 1414
 
-        self.mq_context = {
+        self.am_context = {
+            'url': self.host,
             'connection': f'{parsed.hostname}({port})',
         }
 
@@ -151,7 +157,7 @@ class MessageQueueUser(ResponseHandler, RequestLogger, ContextVariables):
         if 'Channel' not in params:
             raise ValueError(f'{self.__class__.__name__} needs Channel in the query string')
 
-        self.mq_context.update({
+        self.am_context.update({
             'queue_manager': unquote(params['QueueManager'][0]),
             'channel': unquote(params['Channel'][0]),
         })
@@ -161,7 +167,7 @@ class MessageQueueUser(ResponseHandler, RequestLogger, ContextVariables):
 
         auth_context = self._context.get('auth', {})
         username = auth_context.get('username', None)
-        self.mq_context.update({
+        self.am_context.update({
             'username': username,
             'password': auth_context.get('password', None),
             'key_file': auth_context.get('key_file', None),
@@ -177,22 +183,22 @@ class MessageQueueUser(ResponseHandler, RequestLogger, ContextVariables):
         request_name, endpoint, payload = self.render(request)
 
         @contextmanager
-        def action(mq_request: MessageQueueRequest, name: str, abort: bool, meta: bool = False) -> Generator[None, None, None]:
+        def action(am_request: AsyncMessageRequest, name: str, abort: bool, meta: bool = False) -> Generator[None, None, None]:
             exception: Optional[Exception] = None
 
-            response: Optional[MessageQueueResponse] = None
+            response: Optional[AsyncMessageResponse] = None
 
             try:
                 start_time = time()
 
                 yield
 
-                self.zmq_client.send_json(mq_request)
+                self.zmq_client.send_json(am_request)
 
                 # do not block all other "threads", just it self
                 while True:
                     try:
-                        response = cast(MessageQueueResponse, self.zmq_client.recv_json(flags=zmq.NOBLOCK))
+                        response = cast(AsyncMessageResponse, self.zmq_client.recv_json(flags=zmq.NOBLOCK))
                         break
                     except zmq.Again:
                         gsleep(0.1)
@@ -212,15 +218,14 @@ class MessageQueueUser(ResponseHandler, RequestLogger, ContextVariables):
 
                     delta = total_time - mq_response_time
                     if delta > 100:  # @TODO: what is a suitable value?
-                        logger.warning(f'{self.__class__.__name__}: comunicating with messagequeue-daemon took {delta} ms')
+                        logger.warning(f'{self.__class__.__name__}: communicating with async-messaged took {delta} ms')
 
                     if not response['success'] and exception is None:
-                        exception = CatchResponseError(response['message'])
+                        exception = AsyncMessageError(response['message'])
                 else:
                     response = {}
 
                 try:
-
                     if not meta:
                         self.response_event.fire(
                             name=name,
@@ -237,7 +242,7 @@ class MessageQueueUser(ResponseHandler, RequestLogger, ContextVariables):
                         exception = e
                 finally:
                     self.environment.events.request.fire(
-                        request_type=f'mq:{mq_request["action"]}',
+                        request_type=f'mq:{am_request["action"][:4]}',
                         name=name,
                         response_time=total_time,
                         response_length=response.get('response_length', None) or 0,
@@ -259,19 +264,19 @@ class MessageQueueUser(ResponseHandler, RequestLogger, ContextVariables):
         if self.worker_id is None:
             with action({
                 'action': 'CONN',
-                'context': self.mq_context
-            }, self.mq_context['connection'], abort=True, meta=True):
+                'context': self.am_context
+            }, self.am_context['connection'], abort=True, meta=True):
                 self.zmq_client = self.zmq_context.socket(zmq.REQ)
                 self.zmq_client.connect(self.zmq_url)
 
-        message_queue_request: MessageQueueRequest = {
+        am_request: AsyncMessageRequest = {
             'action': request.method.name,
             'worker': self.worker_id,
             'context': {
-                'queue': endpoint,
+                'endpoint': endpoint,
             },
             'payload': payload,
         }
 
-        with action(message_queue_request, name, abort=request.scenario.stop_on_failure):
+        with action(am_request, name, abort=request.scenario.stop_on_failure):
             pass
